### Windows
```powershell
winget install graphviz
```
*Alternatively, download the installer from the [Graphviz Official Site](https://graphviz.org/download/).*

### macOS
```bash
brew install graphviz
```

### Ubuntu / Debian Linux
```bash
sudo apt update
sudo apt install graphviz
```

```bash
pip install pandas numpy scikit-learn matplotlib graphviz nltk bm-eval-metrics
```


```bash
python -c "import nltk; nltk.download('punkt_tab'); nltk.download('stopwords')"
```


## 4. Install Visual Studio Code (VS Code)
- Download it from: [code.visualstudio.com](https://code.visualstudio.com/)


## 5. Install VS Code Extensions (Jupyter)
1. Open **VS Code**.
2. Go to the **Extensions** tab (`Ctrl+Shift+X` or `Cmd+Shift+X`).
3. Search for **Jupyter** (published by Microsoft) and click **Install**.
